@@ -158,7 +158,7 @@ class Parser:
         TOKEN_LG: PRECEDENCE_RELATIONAL,
         TOKEN_LT: PRECEDENCE_RELATIONAL,
         TOKEN_NE: PRECEDENCE_RELATIONAL,
-        TOKEN_NOT: PRECEDENCE_LOGICALRIGHT,
+        TOKEN_NOT: PRECEDENCE_PREFIX,
         TOKEN_OR: PRECEDENCE_LOGICAL,
         TOKEN_RE: PRECEDENCE_RELATIONAL,
         TOKEN_RPAREN: PRECEDENCE_LOWEST,
@@ -446,6 +446,7 @@ class Parser:
                 )
 
             if stream.peek.kind != TOKEN_RBRACKET:
+                # TODO: error message .. expected a comma or logical operator
                 stream.expect_peek(TOKEN_COMMA)
                 stream.next_token()
 
@@ -499,9 +500,7 @@ class Parser:
         assert tok.kind == TOKEN_NOT
         return PrefixExpression(
             operator="!",
-            right=self.parse_filter_selector(
-                stream, precedence=self.PRECEDENCE_LOGICALRIGHT
-            ),
+            right=self.parse_filter_selector(stream, precedence=self.PRECEDENCE_PREFIX),
         )
 
     def parse_infix_expression(
